@@ -149,6 +149,7 @@ typedef enum { uInt, Double, Qtree } type;
 static void *alloc(type t){
   Shelf *shelf = &wall[get_shelf_num()];
 
+
   if ( 
     shelf->nboxes == 0L &&
     !add_box(MIN_BOX_SIZE)
@@ -304,7 +305,9 @@ static void getjaccard(qtree *Q, double *d){
     ++d[0];
   } 
   // denominator: |x V y|
-  ++d[1];
+  if ( Q->n[0] > 0 || Q->n[1] > 0){
+    ++d[1];
+  }
   // clean up and continue
   Q->n[0] = 0;
   Q->n[1] = 0;
@@ -312,7 +315,18 @@ static void getjaccard(qtree *Q, double *d){
   getjaccard(Q->right,d);
 }
 
-
+/* for testing purposes only
+static void print_qtree(qtree *Q, int q){
+  if (Q==NULL) return;
+  Rprintf("q=%d ",q);
+  Rprintf("qgram = {");
+  for(int i = 0; i < q; i++)
+    Rprintf("%03d ",Q->qgram[i]);
+  Rprintf("}");
+  Rprintf("n = [%2.0f %2.0f]\n", Q->n[0], Q->n[1]);
+  print_qtree(Q->left,q);
+  print_qtree(Q->right,q);
+}*/
 
 /*Get qgram distances 
  * Input
@@ -339,7 +353,7 @@ double qgram_dist(
     unsigned int *t, 
     int y,
     unsigned int q, 
-    qtree *Q,
+    qtree **Qp,
     int distance
   ){
   // return -1 when q is larger than the length of the shortest string.
@@ -348,13 +362,15 @@ double qgram_dist(
   // q equals zero. In the R journal paper we used Inf for cases where 
   // q=0 and |s| or |t| > 0
   if ( q == 0 ) return 0.0;
-  
-  double dist[3] = {0,0,0};
-  Q = push_string(s, x, q, Q, 0, 2);
-  if (Q == NULL) return -2.0;
-  Q = push_string(t, y, q, Q, 1, 2);
-  if (Q == NULL) return -2.0;
 
+  double dist[3] = {0,0,0};
+  *Qp = push_string(s, x, q, *Qp, 0, 2);
+  if (*Qp == NULL) return -2.0;
+  *Qp = push_string(t, y, q, *Qp, 1, 2);
+  if (*Qp == NULL) return -2.0;
+
+
+  qtree *Q = *Qp;
   switch ( distance ){
     case 0:
       getdist(Q,dist);
@@ -371,12 +387,13 @@ double qgram_dist(
       }
       break;
     case 2:
-      getjaccard(Q,dist);
+      getjaccard(*Qp,dist);
       dist[0] = 1.0 - dist[0]/dist[1];
       break;
     default:
       break;
   }
+
   return dist[0];
 }
 
